<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_TW" version="2.1">
<context>
    <name>defaultlook</name>
    <message>
        <location filename="defaultlook.ui" line="20"/>
        <location filename="defaultlook.cpp" line="58"/>
        <location filename="defaultlook.cpp" line="502"/>
        <location filename="defaultlook.cpp" line="509"/>
        <location filename="defaultlook.cpp" line="526"/>
        <location filename="defaultlook.cpp" line="537"/>
        <location filename="defaultlook.cpp" line="547"/>
        <source>MX Tweak</source>
        <translation>MX 調校</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="54"/>
        <source>Xfce Settings</source>
        <translation>設定 Xfce</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="63"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the panel&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;自訂邊條&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="77"/>
        <location filename="defaultlook.ui" line="283"/>
        <source>Panel</source>
        <translation>邊條</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="97"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configure window behavior and shortcuts&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;設定視窗行為與捷徑&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="111"/>
        <source>Window Manager</source>
        <translation>視窗管理程式</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="131"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the look of your desktop&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;自訂桌面外觀&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="145"/>
        <source>Appearance</source>
        <translation>外觀</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="223"/>
        <source>About</source>
        <translation>關於</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="234"/>
        <source>Help</source>
        <translation>說明</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="251"/>
        <source>Quit application</source>
        <translation>退出程式</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="254"/>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="261"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="291"/>
        <source>Options</source>
        <translation>選項</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="311"/>
        <source>Backup current panel configuration</source>
        <translation>備份目前使用的邊條設定</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="318"/>
        <source>Restore backup panel configuration</source>
        <translation>由備份檔回復邊條設定</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="325"/>
        <source>Restore default panel</source>
        <translation>回復成預設邊條</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="338"/>
        <source>Affects 1st panel</source>
        <translation>影響到第一條邊條</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="345"/>
        <source>Display panel vertically</source>
        <translation>邊條垂直顯示</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="365"/>
        <source>Bottom</source>
        <translation>下側</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="370"/>
        <source>Top</source>
        <translation>上側</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="378"/>
        <source>Display panel horizontally</source>
        <translation>邊條水平顯示</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="398"/>
        <source>Left</source>
        <translation>左側</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="403"/>
        <source>Right</source>
        <translation>右側</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="411"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Affects all panels&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;影響到所有邊條&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="431"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Buttons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;視窗按鈕&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="446"/>
        <location filename="defaultlook.ui" line="549"/>
        <location filename="defaultlook.ui" line="740"/>
        <location filename="defaultlook.ui" line="894"/>
        <location filename="defaultlook.ui" line="936"/>
        <source>Apply</source>
        <translation>使用</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="469"/>
        <source>Theme</source>
        <translation>佈景</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="483"/>
        <source>Theme Options</source>
        <translation>佈景選項 </translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="513"/>
        <source>Fix some website fields when using dark theme</source>
        <translation>使用暗色系佈景時，校正某些網站的欄位</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="516"/>
        <source>Firefox dark theme tweak</source>
        <translation>Firefox 暗色系佈景調校</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="523"/>
        <source>Fix HexChat input box in dark theme</source>
        <translation>使用暗色系佈景時，校正 HexChat 的輸入區</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="575"/>
        <source>Undo</source>
        <translation>復原</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="582"/>
        <source>Preview</source>
        <translation>預覽</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="589"/>
        <source>Remove User Theme Set</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="defaultlook.ui" line="600"/>
        <source>Save Current Settings as a Theme Set</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="defaultlook.ui" line="614"/>
        <location filename="defaultlook.ui" line="760"/>
        <source>Compositor</source>
        <translation>桌面排版程式</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="635"/>
        <source>Launch compton-conf configuration tool</source>
        <translation>啟動 compton-conf 設定工具</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="638"/>
        <source>Compton settings</source>
        <translation>設定 Compton</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="662"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;設定 Xfce 的桌面排版程式&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="665"/>
        <source>Xfwm Settings</source>
        <translation>設定 Xfwm</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="689"/>
        <source>None</source>
        <translation>無</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="694"/>
        <source>Xfwm (Xfce) Compositor</source>
        <translation>Xfwm（Xfce）桌面排版程式</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="699"/>
        <source>Compton </source>
        <translation>Compton</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="707"/>
        <source>Edit compton.conf directly in text editor</source>
        <translation>利用文字編緝程式直接修改 compton.conf</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="710"/>
        <source>Edit compton.conf</source>
        <translation>編緝 compton.conf</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="767"/>
        <source>Transparency and shadow options</source>
        <translation>視窗透明化與投射陰影的選項</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="774"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Changing the VBlank mode may help alleviate some screen tearing issues.  See Help for more information.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="defaultlook.ui" line="777"/>
        <source>VBlank</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="defaultlook.ui" line="785"/>
        <source>auto</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="defaultlook.ui" line="790"/>
        <source>glx</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="defaultlook.ui" line="795"/>
        <source>xpresent</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="defaultlook.ui" line="800"/>
        <source>off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="defaultlook.ui" line="811"/>
        <source>Config Options</source>
        <translation>設定選項</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="819"/>
        <source>Reset Lightdm (login screen) to system default theme</source>
        <translation>將 Lightdm（登入畫面）回復成系統預設的佈景</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="826"/>
        <source>Reset Thunar custom right-click actions to system defaults</source>
        <translation>將 Thunar 當中右鍵的自訂動作回復成系統預設的動作</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="833"/>
        <source>Use intel driver instead of default &quot;modsetting&quot; driver (requires restart)</source>
        <translation>使用 intel 驅動程式，而不是預設的「modsetting」驅動程式（必須重新開機）</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="840"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
        <translation>註：現所採用的 /etc/X11/xorg.conf.d/20-intel.conf 會備份到家目錄當中</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="847"/>
        <source>Use tearfree amdgpu option</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="defaultlook.ui" line="854"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="defaultlook.ui" line="861"/>
        <source>Use tearfree radeon driver option</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="defaultlook.ui" line="868"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="defaultlook.ui" line="908"/>
        <source>Other</source>
        <translation>其它</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="916"/>
        <source>Enable single-click on desktop</source>
        <translation>在桌面上啟用游標單擊</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="923"/>
        <source>Enable single-click in Thunar File Manager</source>
        <translation>在 Thunar 檔案管理員中啟用游標單擊</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="960"/>
        <source>Show systray (notification area) frame</source>
        <translation>顯示通知區域的外框</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="967"/>
        <source>Show windows from all workspaces in panel</source>
        <translation>在邊條中顯示來自所有工作區的視窗</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="974"/>
        <source>Enable mounting of internal drives by non-root users</source>
        <translation>容許並非 root 的使用者掛載內接式硬碟</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="981"/>
        <source>Disable shortening of long filenames on the desktop</source>
        <translation>在桌面上，不把過長檔名簡化顯示</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="988"/>
        <source>Enable hibernate on Log Out menu </source>
        <translation>在登出選單中啟用休眠選項</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="995"/>
        <source>                   note: to hibernate, swap needs to be &gt;= RAM</source>
        <translation>註：若欲休眠，swap 必須大於 RAM</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="501"/>
        <source>About MX Tweak</source>
        <translation>關於 MX 調校</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="502"/>
        <source>Version: </source>
        <translation>版本：</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="503"/>
        <source>App for quick default ui theme changes and tweaks</source>
        <translation>本程式可快速更換與調校預設介面佈景</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="505"/>
        <source>Copyright (c) MX Linux</source>
        <translation>版權所有 (c) MX Linux</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="506"/>
        <location filename="defaultlook.cpp" line="509"/>
        <source>License</source>
        <translation>授權條款</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="507"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="538"/>
        <source>Finished! Firefox may require a restart for changes to take effect</source>
        <translation>完成！可能需要重新啟動 Firefox，這些變動才會生效。</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="548"/>
        <source>This app is Xfce-only</source>
        <translation>本程式僅支援 Xfce</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="690"/>
        <source>Panel settings</source>
        <translation>邊條設定</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="691"/>
        <source> Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
        <translation>目前所採用的邊條設定已備份，放在家目錄下的一隠藏資料夾中（~./restore）</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="1117"/>
        <source>Choose a theme set</source>
        <translation>選擇一套佈景組合</translation>
    </message>
</context>
<context>
    <name>remove_user_theme_set</name>
    <message>
        <location filename="remove_user_theme_set.ui" line="14"/>
        <source>Remove User Theme Set</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>theming_to_tweak</name>
    <message>
        <location filename="theming_to_tweak.ui" line="14"/>
        <source>New Theme Set</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="theming_to_tweak.ui" line="20"/>
        <source>Enter name for new theme set</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>window_buttons</name>
    <message>
        <location filename="window_buttons.ui" line="14"/>
        <location filename="window_buttons.cpp" line="37"/>
        <source>Window Buttons</source>
        <translation>視窗按鈕</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="28"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Appearance&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;外觀&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="35"/>
        <source>Show button labels</source>
        <translation>顯示按鈕標籤</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="42"/>
        <source>Show flat buttons</source>
        <translation>顯示扁平按鈕</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="49"/>
        <source>Show handle</source>
        <translation>顯示控制把</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="56"/>
        <source>Sorting Order:</source>
        <translation>排序：</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="64"/>
        <source>Timestamp</source>
        <translation>時間戳記</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="69"/>
        <source>Group title and timestamp</source>
        <translation>群組標題與時間戳記</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="74"/>
        <source>Window Title</source>
        <translation>視窗標題</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="79"/>
        <source>Group title and window title</source>
        <translation>群組標題與視窗標題</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="84"/>
        <source>None, allow drag-and-drop</source>
        <translation>無，允許拖放</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="92"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Behavior&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;行為&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="99"/>
        <source>Window grouping:</source>
        <translation>視窗群組：</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="107"/>
        <source>Never</source>
        <translation>永不</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="112"/>
        <source>Always</source>
        <translation>總是</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="120"/>
        <source>Middle click action:</source>
        <translation>中鍵點擊動作：</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="128"/>
        <source>Nothing</source>
        <translation>不動作</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="133"/>
        <source>Close window</source>
        <translation>關閉視窗</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="138"/>
        <source>Minimize window</source>
        <translation>最小化視窗</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="146"/>
        <source>Restore minimized windows to current workspace</source>
        <translation>還原最小化視窗至目前工作區</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="153"/>
        <source>Draw window frame when hovering over a button</source>
        <translation>當滑鼠停在按鈕上時繪製視窗框架</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="160"/>
        <source>Switch windows using the mouse wheel</source>
        <translation>用滑鼠滾輪切換視窗</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="167"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtering&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;過濾方式&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="174"/>
        <source>Show windows from all workspaces or viewports</source>
        <translation>顯示所有工作區視域內的視窗</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="181"/>
        <source>Show only minimized windows</source>
        <translation>只顯示最小化的視窗</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="188"/>
        <source>Show windows from all monitors</source>
        <translation>顯示所有螢幕的視窗</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="238"/>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
</context>
<context>
    <name>xfwm_compositor_settings</name>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="14"/>
        <source>Dialog</source>
        <translation>對話視窗</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="42"/>
        <source>Popup Windows</source>
        <translation>彈出式視窗</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="49"/>
        <source>Windows during move</source>
        <translation>移動視窗時</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="56"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Opacity Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;不透明度設定&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="79"/>
        <source>Window decorations</source>
        <translation>視窗裝飾</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="86"/>
        <source>Show shadows under dock windows</source>
        <translation>在塢區視窗下顯示陰影</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="93"/>
        <source>Show shadows under popup windows</source>
        <translation>在彈出式視窗下顯示陰影</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="100"/>
        <source>Windows during resize</source>
        <translation>調整視窗大小時</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="123"/>
        <source>Show shadows under regular windows</source>
        <translation>在一般視窗下顯示陰影</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="130"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Feature Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;功能設定&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="137"/>
        <source>Show windows preview in place of icons when cycling</source>
        <translation>循環切換時，顯示視窗預覽而非圖示</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="144"/>
        <source>Display fullscreen overlay windows directly</source>
        <translation>以直接覆蓋視窗的方式顯示全螢幕</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="183"/>
        <source>Inactive windows</source>
        <translation>非活動中視窗</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="190"/>
        <source>Synchronize drawing to vertical blank</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="212"/>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.cpp" line="39"/>
        <source>Xfwm Compositor Settings</source>
        <translation>設定 Xfwm 桌面排版程式</translation>
    </message>
</context>
</TS>